pub struct InfoGetJobKoidResponder { /* private fields */ }Implementations
Sourceimpl InfoGetJobKoidResponder
impl InfoGetJobKoidResponder
Sourcepub fn send(self, payload: &InfoGetJobKoidResponse) -> Result<(), Error>
pub fn send(self, payload: &InfoGetJobKoidResponse) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
payload: &InfoGetJobKoidResponse,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, payload: &InfoGetJobKoidResponse, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.