VmoReference

Struct VmoReference 

pub struct VmoReference {
    pub process_name: Option<String>,
    pub pid: Option<u64>,
    pub fd: Option<i32>,
    pub koid: Option<u64>,
    /* private fields */
}

Fields

process_name: Option<String>

The name of the process containing a file backed by the vmo.

pid: Option<u64>

The Starnix pid of the process containing a file backed by the vmo.

fd: Option<i32>

The file descriptor number in the process that refers to the vmo.

koid: Option<u64>

The koid of the vmo.